@@ -4,7 +4,7 @@ import shutil
 import subprocess
 import time
 import uuid
-from typing import Optional
+from typing import Optional, Union
 
 from cavass._io import read_mat, save_mat, ensure_output_file_dir_existence
 
@@ -24,7 +24,7 @@ def env():
     return None
 
 
-def execute_cmd(cavass_cmd):
+def execute_cavass_cmd(cavass_cmd):
     p = subprocess.Popen(cavass_cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=env())
     r, e = p.communicate()
     try:
@@ -57,7 +57,7 @@ def get_image_resolution(input_file):
         raise FileNotFoundError(f"Input file {input_file} not found.")
 
     cmd = f"get_slicenumber {input_file} -s"
-    r = execute_cmd(cmd)
+    r = execute_cavass_cmd(cmd)
     r = r.split("\n")[2]
     r = r.split(" ")
     r = tuple(map(lambda x: int(x), r))
@@ -79,7 +79,7 @@ def get_voxel_spacing(input_file):
         raise FileNotFoundError(f"Input file {input_file} not found.")
 
     cmd = f"get_slicenumber {input_file} -s"
-    r = execute_cmd(cmd)
+    r = execute_cavass_cmd(cmd)
     r = r.split("\n")[0]
     r = r.split(" ")
     r = tuple(map(lambda x: float(x), r))
@@ -100,7 +100,7 @@ def get_slice_number(input_file):
         raise FileNotFoundError(f"Input file {input_file} not found.")
 
     cmd = f"get_slicenumber {input_file} -s"
-    r = execute_cmd(cmd)
+    r = execute_cavass_cmd(cmd)
     results = []
     for each_line in r.splitlines():
         results.extend(each_line.split(" "))
@@ -136,7 +136,7 @@ def read_cavass_file(input_file, first_slice=None, last_slice=None, sleep_time=0
     else:
         cvt2mat = f"exportMath {input_file} matlab {output_file} {first_slice} {last_slice}"
     try:
-        execute_cmd(cvt2mat)
+        execute_cavass_cmd(cvt2mat)
         if sleep_time > 0:
             time.sleep(sleep_time)
         ct = read_mat(output_file)
@@ -167,7 +167,7 @@ def copy_pose(input_file_1, input_file_2, output_file):
     made_output_dir, output_dir = ensure_output_file_dir_existence(output_file)
 
     try:
-        execute_cmd(f"copy_pose {input_file_1} {input_file_2} {output_file}")
+        execute_cavass_cmd(f"copy_pose {input_file_1} {input_file_2} {output_file}")
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
@@ -179,8 +179,8 @@ def copy_pose(input_file_1, input_file_2, output_file):
 def save_cavass_file(output_file,
                      data,
                      binary=False,
-                     size: Optional[list[int], tuple[int, ...]] = None,
-                     spacing: Optional[list[float], tuple[float, ...]] = None,
+                     size: Optional[Union[list[int], tuple[int, ...]]] = None,
+                     spacing: Optional[Union[list[float], tuple[float, ...]]] = None,
                      pose_reference_file=None):
     """
     Save data as CAVASS format. Do not provide spacing and reference_file at the same time. Recommend to use binary for
@@ -219,7 +219,7 @@ def save_cavass_file(output_file,
     if not binary:
         if pose_reference_file is None:
             try:
-                execute_cmd(f"importMath {tmp_mat} matlab {output_file} {size} {spacing}")
+                execute_cavass_cmd(f"importMath {tmp_mat} matlab {output_file} {size} {spacing}")
             except Exception as e:
                 if made_output_dir and os.path.isdir(output_dir):
                     shutil.rmtree(output_dir)
@@ -231,7 +231,7 @@ def save_cavass_file(output_file,
             tmp_file = os.path.join(output_dir, f"tmp_{uuid.uuid1()}.IM0")
             tmp_files.append(tmp_file)
             try:
-                execute_cmd(f"importMath {tmp_mat} matlab {tmp_file} {size}")
+                execute_cavass_cmd(f"importMath {tmp_mat} matlab {tmp_file} {size}")
                 copy_pose(tmp_file, pose_reference_file, output_file)
             except Exception as e:
                 if made_output_dir and os.path.isdir(output_dir):
@@ -246,8 +246,8 @@ def save_cavass_file(output_file,
             tmp_file = os.path.join(output_dir, f"tmp_{uuid.uuid1()}.IM0")
             tmp_files.append(tmp_file)
             try:
-                execute_cmd(f"importMath {tmp_mat} matlab {tmp_file} {size} {spacing}")
-                execute_cmd(f"ndthreshold {tmp_file} {output_file} 0 1 1")
+                execute_cavass_cmd(f"importMath {tmp_mat} matlab {tmp_file} {size} {spacing}")
+                execute_cavass_cmd(f"ndthreshold {tmp_file} {output_file} 0 1 1")
             except Exception as e:
                 if made_output_dir and os.path.isdir(output_dir):
                     shutil.rmtree(output_dir)
@@ -259,7 +259,7 @@ def save_cavass_file(output_file,
             tmp_file = os.path.join(output_dir, f"tmp_{uuid.uuid1()}.IM0")
             tmp_files.append(tmp_file)
             try:
-                execute_cmd(f"importMath {tmp_mat} matlab {tmp_file} {size}")
+                execute_cavass_cmd(f"importMath {tmp_mat} matlab {tmp_file} {size}")
             except Exception as e:
                 if made_output_dir and os.path.isdir(output_dir):
                     shutil.rmtree(output_dir)
@@ -271,7 +271,7 @@ def save_cavass_file(output_file,
             tmp_file1 = os.path.join(output_dir, f"tmp_{uuid.uuid1()}.BIM")
             tmp_files.append(tmp_file1)
             try:
-                execute_cmd(f"ndthreshold {tmp_file} {tmp_file1} 0 1 1")
+                execute_cavass_cmd(f"ndthreshold {tmp_file} {tmp_file1} 0 1 1")
                 copy_pose(tmp_file1, pose_reference_file, output_file)
             except Exception as e:
                 if made_output_dir and os.path.isdir(output_dir):
@@ -305,7 +305,7 @@ def bin_ops(input_file_1, input_file_2, output_file, op):
 
     cmd_str = f"bin_ops {input_file_1} {input_file_2} {output_file} {op}"
     try:
-        execute_cmd(cmd_str)
+        execute_cavass_cmd(cmd_str)
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
@@ -330,7 +330,7 @@ def median2d(input_file, output_file, mode=0):
     made_output_dir, output_dir = ensure_output_file_dir_existence(output_file)
 
     try:
-        execute_cmd(f"median2d {input_file} {output_file} {mode}")
+        execute_cavass_cmd(f"median2d {input_file} {output_file} {mode}")
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
@@ -363,7 +363,7 @@ def export_math(input_file, output_file, output_file_type="matlab", first_slice=
     made_output_dir, output_dir = ensure_output_file_dir_existence(output_file)
 
     try:
-        execute_cmd(f"exportMath {input_file} {output_file_type} {output_file} {first_slice} {last_slice}")
+        execute_cavass_cmd(f"exportMath {input_file} {output_file_type} {output_file} {first_slice} {last_slice}")
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
@@ -393,7 +393,7 @@ def render_surface(input_bim_file, output_file):
     interpl_tmp_bim_file = os.path.join(output_dir, f"{uuid.uuid1()}.BIM")
     ndinterpolate_cmd = f"ndinterpolate {input_bim_file} {interpl_tmp_bim_file} 0 `get_slicenumber {input_bim_file} -s | head -c 9` `get_slicenumber {input_bim_file} -s | head -c 9` `get_slicenumber {input_bim_file} -s | head -c 9` 1 1 1 1 `get_slicenumber {input_bim_file}`"
     try:
-        execute_cmd(ndinterpolate_cmd)
+        execute_cavass_cmd(ndinterpolate_cmd)
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
@@ -404,7 +404,7 @@ def render_surface(input_bim_file, output_file):
     gaussian_tmp_im0_file = os.path.join(output_dir, f"{uuid.uuid1()}.IM0")
     gaussian_cmd = f"gaussian3d {interpl_tmp_bim_file} {gaussian_tmp_im0_file} 0 1.500000"
     try:
-        execute_cmd(gaussian_cmd)
+        execute_cavass_cmd(gaussian_cmd)
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
@@ -416,7 +416,7 @@ def render_surface(input_bim_file, output_file):
 
     render_cmd = f"track_all {gaussian_tmp_im0_file} {output_file} 1.000000 115.000000 254.000000 26 0 0"
     try:
-        execute_cmd(render_cmd)
+        execute_cavass_cmd(render_cmd)
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
@@ -464,7 +464,7 @@ def ndvoi(input_file: str, output_file: str, mode: int = 0,
         raise FileNotFoundError(f"Input file {input_file} not found.")
 
     if mode not in [0, 1]:
-        raise ValueError(f"{mode} is not a valid mode. Support 0 and 1 (0=foreground, 1=background)")
+        raise ValueError(f"{mode} is not a valid mode. Support 0 and 1 (0=foreground, 1=background).")
 
     made_output_dir, output_dir = ensure_output_file_dir_existence(output_file)
 
@@ -478,7 +478,7 @@ def ndvoi(input_file: str, output_file: str, mode: int = 0,
     if max_slice_dim_4 is not None:
         cmd += f" {max_slice_dim_4}"
     try:
-        execute_cmd(cmd)
+        execute_cavass_cmd(cmd)
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
@@ -529,7 +529,7 @@ def matched_reslice(file_to_reslice: str, file_to_match: str,
     if new_loc is not None:
         cmd += f" {new_loc}"
     try:
-        execute_cmd(cmd)
+        execute_cavass_cmd(cmd)
     except Exception as e:
         if made_output_dir and os.path.isdir(output_dir):
             shutil.rmtree(output_dir)
